@@ -8,7 +8,7 @@
 
 echo -----
 
-./wasmsign2 show -i z2.wasm -v
+./wasmsign2 -v show -i z2.wasm
 
 ./wasmsign2 sign -k secret.key -i z2.wasm -o z3.wasm
 
@@ -20,5 +20,5 @@ echo -----
 
 ./wasmsign2 verify -i z4.wasm -K public.key && error "should fail"
 ./wasmsign2 verify -i z4.wasm -K public.key2
-./wasmsign2 verify -i z4.wasm -K public.key2 -s 'name' && error "should fail"
+./wasmsign2 verify -i z4.wasm -K public.key2 -s 'name'
 ./wasmsign2 verify -i z4.wasm -K public.key2 -s 'debug|name'
